@@ -112,9 +112,9 @@ static QVariantHash memberHash(const KContacts::ContactGroup::Data &data)
     contact.setFormattedName(data.name());
     contact.insertEmail(data.email());
 
-    const QString emailLink = QStringLiteral("<a href=\"mailto:") +
-                              QString::fromLatin1(QUrl::toPercentEncoding(contact.fullEmail())) +
-                              QStringLiteral("\">%1</a>").arg(contact.preferredEmail());
+    const QString emailLink = QStringLiteral("<a href=\"mailto:")
+                              +QString::fromLatin1(QUrl::toPercentEncoding(contact.fullEmail()))
+                              +QStringLiteral("\">%1</a>").arg(contact.preferredEmail());
 
     setHashField(memberObject, QStringLiteral("emailLink"), emailLink);
 
@@ -146,7 +146,8 @@ QString GrantleeContactGroupFormatter::toHtml(HtmlForm form) const
         Akonadi::ContactGroupExpandJob *job = new Akonadi::ContactGroupExpandJob(group);
         if (job->exec()) {
             group.removeAllContactData();
-            foreach (const KContacts::Addressee &contact, job->contacts()) {
+            const KContacts::Addressee::List lstContacts = job->contacts();
+            for (const KContacts::Addressee &contact : lstContacts) {
                 group.append(KContacts::ContactGroup::Data(contact.realName(), contact.preferredEmail()));
             }
         }
